#!/bin/bash

set -e

log_file=/linuxcash/logs/current/upgrade_to_jammy.log
status_file=/linuxcash/cash/data/jammy.upgrade.status

log()
{
    echo `date` "$1" | tee -a "$log_file"
}

# Отключаем диалоги
export DEBIAN_FRONTEND=noninteractive

while :; do
    STATUS=
    [ -f "$status_file" ] && STATUS=$(cat "$status_file")

    case "$STATUS" in
        '')
            if [ -x /linuxcash/cash/data/db/upgradeToMySQL8.sh ]; then
                log "Обновляем MySQL до 8й версии"
                /linuxcash/cash/data/db/upgradeToMySQL8.sh
            fi
            ;;
        1)
            log "Добавляем jammy репозиторий для apt"
            sed -e 's/bionic/jammy/g' -i /etc/apt/sources.list.d/artix.list
            ;;
        2)
            log "Обновляемся на сколько можно без конфликтов"
            apt-get update
            apt-get -o 'Dpkg::Options::=--force-confold' upgrade -y --allow-downgrades
            ;;
        3)
            log "Обновляем systemd"
            apt-get upgrade -y udev systemd nfs-common --allow-downgrades
            ;;
        4)
            log "Обновляем util-linux"
            apt-get -o 'Dpkg::Options::=--force-overwrite' install -y util-linux
            ;;
        5)
            log "Обновляем основные пакеты"
            PACKAGES=(python-is-python3)
            for pkg in artix-pos artix-sst-sco artix-pos-sco; do
                if dpkg-query -s "$pkg" >/dev/null 2>/dev/null; then
                    PACKAGES+=("$pkg")
                fi
            done
            aptitude -o 'Dpkg::Options::=--force-confold' dist-upgrade -y "${PACKAGES[@]}"
            ;;
        6)
            log "Обновляем оставшиеся пакеты"
            apt-get -o 'Dpkg::Options::=--force-confold' dist-upgrade -y --allow-downgrades
            ;;
        7)
            apt-get update
            ;;
        *)
            log "Удаляем artix-upgrade-bionic"
            apt-get purge -y artix-upgrade-bionic update-manager-core ubuntu-release-upgrader-core
            break
            ;;
    esac

    ((STATUS+=1))
    echo "$STATUS" > "$status_file"
done
